hotspot/src/share/vm/opto/memnode.hpp
changeset 2022 28ce8115a91d
parent 1500 bea9a90f3e8f
child 2131 98f9cef66a34
child 2105 347008ce7984
--- a/hotspot/src/share/vm/opto/memnode.hpp	Wed Jan 21 11:18:38 2009 -0800
+++ b/hotspot/src/share/vm/opto/memnode.hpp	Mon Jan 26 16:22:12 2009 +0100
@@ -207,11 +207,11 @@
   virtual BasicType memory_type() const { return T_BYTE; }
 };
 
-//------------------------------LoadCNode--------------------------------------
-// Load a char (16bits unsigned) from memory
-class LoadCNode : public LoadNode {
+//------------------------------LoadUSNode-------------------------------------
+// Load an unsigned short/char (16bits unsigned) from memory
+class LoadUSNode : public LoadNode {
 public:
-  LoadCNode( Node *c, Node *mem, Node *adr, const TypePtr* at, const TypeInt *ti = TypeInt::CHAR )
+  LoadUSNode( Node *c, Node *mem, Node *adr, const TypePtr* at, const TypeInt *ti = TypeInt::CHAR )
     : LoadNode(c,mem,adr,at,ti) {}
   virtual int Opcode() const;
   virtual uint ideal_reg() const { return Op_RegI; }